import cloudfront = require('@aws-cdk/aws-cloudfront');
import s3 = require('@aws-cdk/aws-s3');
import s3deploy = require('@aws-cdk/aws-s3-deployment');
import cdk = require('@aws-cdk/core');
import { Construct } from '@aws-cdk/core';
export interface StaticSiteProps {
    /**
     * Domain name to host static site
     */
    readonly domainName: string;
    /**
     * Subdomain to host static site
     */
    readonly siteSubDomain: string;
    /**
     * Source of static site files to serve
     */
    readonly staticSiteFiles: s3deploy.ISource;
    /**
     * Provide a bucket for the static pages, if none is provided a default bucket is created
     */
    readonly staticSiteBucket?: s3.IBucket;
    /**
     * Bucket removal policy for default bucket
     * @default cdk.RemovalPolicy cdk.RemovalPolicy.RETAIN
     */
    readonly staticSiteBucketRemovalPolicy?: cdk.RemovalPolicy;
}
/**
 * Static site infrastructure, which deploys site content to an S3 bucket.
 *
 * The site redirects from HTTP to HTTPS, using a CloudFront distribution,
 * Route53 alias record, and ACM certificate.
 */
export declare class CdkStaticSite extends cdk.Construct {
    /** @returns the s3 bucket where the site files are located */
    readonly bucket: s3.IBucket;
    readonly cloudfrontDistribution: cloudfront.CloudFrontWebDistribution;
    constructor(parent: Construct, name: string, props: StaticSiteProps);
}
export interface StaticSitePipelineProps {
    /**
     * Github Project to deploy from
     */
    readonly githubOwner: string;
    /**
     * Github Repo to deploy from
     */
    readonly githubRepo: string;
    /**
     * Github OAuth token
     */
    readonly githubOAuthToken: cdk.SecretValue;
    /**
     * Name of stack to deploy
     */
    readonly stackName: string;
}
export declare class CdkStaticSitePipeline extends cdk.Construct {
    constructor(parent: Construct, name: string, props: StaticSitePipelineProps);
}
